#
# spec file for package arm-trusted-firmware
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define platform qemu%{nil}

%if "%{platform}" == "a3700" || "%{platform}" == "imx8mq"
# Debug build not supported for UART boot on a3700
# Debug build is too big on imx8mq, see: https://developer.trustedfirmware.org/T626
%global debug_build 0
%else
%global debug_build 1
%endif

# Patch151 fixes the build with GCC11 - https://github.com/MarvellEmbeddedProcessors/A3700-utils-marvell/issues/22
%bcond_without A3700_tools

%bcond_with atf_optee

%if %{with atf_optee}
%define use_optee 1
%if "%{platform}" == "" || "%{platform}" == "tegra186" || "%{platform}" == "tegra210" || "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399" || "%{platform}" == "rpi4"
# OP-TEE not available
%define use_optee 0
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin" || "%{platform}" == "imx8qm" || "%{platform}" == "imx8qx" || "%{platform}" == "imx8mq" || "%{platform}" == "imx8mm" || "%{platform}" == "sun50i_a64" || "%{platform}" == "sun50i_h6" || "%{platform}" == "zynqmp"
# TBD
%define use_optee 0
%endif
%else
%define use_optee 0
%endif

%if "%{platform}" == ""
Name:           arm-trusted-firmware
%else
Name:           arm-trusted-firmware-%{platform}
%endif
Version:        2.6
Release:        10.1
%define srcversion 2.6
%define mv_ddr_ver armada-atf-master
%define mv_bin_ver 10.0.1.0
%define a3700_utils_ver master
Summary:        Arm Trusted Firmware-A
License:        BSD-3-Clause
Group:          System/Boot
URL:            https://www.trustedfirmware.org/
Source:         https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/snapshot/trusted-firmware-a-%{srcversion}.tar.gz
Source1:        mv-ddr-marvell-%{mv_ddr_ver}.tar.gz
Source2:        A3700-utils-marvell-%{a3700_utils_ver}.tar.gz
Source3:        binaries-marvell-%{mv_bin_ver}.tar.gz
Patch1:         atf-allow-non-git-dir.patch
Patch150:       A3700_utils-drop-git.patch
Patch151:       fix-A3700-gcc11.patch
%if "%{platform}" != ""
#!BuildIgnore: gcc-PIE
%endif
%if "%{platform}" == "a3700"
BuildRequires:  arm-trusted-firmware-tools
BuildRequires:  cross-arm-none-newlib-devel
BuildRequires:  gcc-c++
BuildRequires:  libcryptopp-devel
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "rk3399"
BuildRequires:  cross-arm-none-gcc%{gcc_version}
%endif
%if "%{platform}" == "a80x0_mcbin" && 0
BuildRequires:  edk2-Armada80x0McBin
%endif
%if "%{platform}" == "hikey"
BuildRequires:  edk2-hikey
%endif
%if "%{platform}" == "hikey960"
BuildRequires:  edk2-hikey960
%endif
%if "%{platform}" == ""
BuildRequires:  gcc-c++
%endif
BuildRequires:  git
%if "%{platform}" == ""
BuildRequires:  libcryptopp-devel
%endif
BuildRequires:  libopenssl-devel
%if %{use_optee}
%if "%{platform}" == "qemu"
BuildRequires:  optee-qemu-armv8a
%else
%if "%{platform}" == "a3700"
BuildRequires:  optee-armada3700
%else
%if "%{platform}" == "a80x0_mcbin"
BuildRequires:  optee-armada7k8k
%else
BuildRequires:  optee-%{platform}
%endif
%endif
%endif
%endif
%if "%{platform}" == "qemu"
BuildRequires:  qemu-uefi-aarch64
%endif
%if "%{platform}" == "rpi3" || "%{platform}" == "rpi4"
# For /boot/vc
BuildRequires:  raspberrypi-firmware
%endif
%if "%{platform}" == "a3700"
BuildRequires:  u-boot-mvebuespressobin-88f3720
%endif
%if "%{platform}" == "a80x0_mcbin" && 1
BuildRequires:  u-boot-mvebumcbin-88f8040
%endif
%if "%{platform}" == "hikey"
BuildRequires:  u-boot-hikey
%endif
%if "%{platform}" == "poplar"
BuildRequires:  u-boot-poplar
%endif
%if "%{platform}" == "rpi3"
BuildRequires:  u-boot-rpi3
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if "%{platform}" != ""
BuildArch:      noarch
ExclusiveArch:  aarch64
%endif
%if "%{platform}" == "rpi4"
Supplements:    modalias(of:N*T*Cbrcm%2Cbcm2711*C*)
%endif

%description
Trusted Firmware-A (TF-A) provides a reference implementation of secure world
software for Armv7-A and Armv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3).

%if "%{platform}" == "poplar"
%package devel
Summary:        ARM Trusted Firmware -- %{platform} development files
License:        BSD-3-Clause
Group:          System/Boot
Requires:       %{name} = %{version}

%description devel
ARM Trusted Firmware provides a reference implementation of
secure world software for ARMv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3). It implements various ARM interface standards,
such as the Power State Coordination Interface (PSCI),
Trusted Board Boot Requirements (TBBR, ARM DEN0006C-1) and
SMC Calling Convention. As far as possible the code is designed for reuse
or porting to other ARMv8-A model and hardware platforms.

This sub-package contains development files.
%endif

%if "%{platform}" == ""
%package tools
Summary:        Tools for ARM Trusted Firmware-A
Group:          System/Boot

%description tools
Trusted Firmware-A (TF-A) provides a reference implementation of
secure world software for ARMv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3). It implements various ARM interface standards,
such as the Power State Coordination Interface (PSCI),
Trusted Board Boot Requirements (TBBR, ARM DEN0006C-1) and
SMC Calling Convention. As far as possible the code is designed for reuse
or porting to other ARMv8-A model and hardware platforms.

This package contains fiptool.
%endif

%prep
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
%if "%{platform}" == "a3700"
%setup -q -n trusted-firmware-a-%{srcversion} -a 1 -a 2
%else
%setup -q -n trusted-firmware-a-%{srcversion} -a 1 -a 3
%endif
# git repo or branch.txt file are expected
echo "%{mv_ddr_ver}" > mv-ddr-marvell-%{mv_ddr_ver}/branch.txt
%else
%if "%{platform}" == ""
%setup -q -n trusted-firmware-a-%{srcversion} -a 2
%else
%setup -q -n trusted-firmware-a-%{srcversion}
%endif
%endif
%if "%{platform}" == "" || "%{platform}" == "a3700"
pushd A3700-utils-marvell-%{a3700_utils_ver}
# git repo or branch.txt file are expected
echo "%{a3700_utils_ver}" >  branch.txt
# Remove any pre-built x86 Linux binaries
rm -f wtptp/linux/*
%if "%{platform}" != ""
install -m 0755 %{_bindir}/TBB wtptp/linux/tbb_linux
%endif
%patch150 -p1
%patch151 -p1
popd
%endif
%patch1 -p1

%build
export BUILD_MESSAGE_TIMESTAMP="\"$(date -d "$(head -n 2 %{_sourcedir}/arm-trusted-firmware.changes | tail -n 1 | cut -d- -f1 )" -u "+%%H:%%M:%%S, %%b %%e %%Y")\""
%if "%{platform}" == "a3700"
export CRYPTOPP_LIBDIR=%{_libdir}
export CRYPTOPP_INCDIR=%{_includedir}/cryptopp
%endif

%if "%{platform}" == ""

make %{?_smp_mflags} V=1 fiptool

%if %{with A3700_tools}
pushd A3700-utils-marvell-%{a3700_utils_ver}
make %{?_smp_mflags} -C wtptp/src/TBB_Linux -f TBB_linux.mak INCDIR=%{_includedir}/cryptopp LIBDIR=%{_libdir}
make %{?_smp_mflags} -C wtptp/src/Wtpdownloader_Linux -f makefile.mk
popd
%endif

%else
%if "%{platform}" == "a3700"
export CROSS_CM3=arm-none-eabi-
%define variants ebin_512M_spinor ebin_v3_1G_spinor ebin_v5_2G_spinor ebin_v7_1G_spinor ebin_v7_2G_spinor
for variant in %{variants}; do
  partnum=0
  case "${variant}" in
  ebin_*)
    clockspreset=CPU_1000_DDR_800
    ;;
  esac
  case "${variant}" in
  ebin_512M_*)
    ddr_topology=0
    ;;
  ebin_v3_1G_*)
    ddr_topology=2
    ;;
  ebin_v5_2G_*)
    ddr_topology=7
    ;;
  ebin_v7_1G_*)
    ddr_topology=5
    ;;
  ebin_v7_2G_*)
    ddr_topology=6
    ;;
  esac
  case "${variant}" in
  *_emmc)    bootdev=EMMCNORM ;;
  *_sata)    bootdev=SATA ;;
  *_spinand) bootdev=SPINAND ;;
  *_spinor)  bootdev=SPINOR ;;
  esac
  make distclean
%endif
%if "%{platform}" == "poplar"
for dram_size in one_gig two_gig; do
%endif
make \
%if "%{platform}" != "a3700" && "%{platform}" != "a80x0_mcbin"
     %{?_smp_mflags} \
%endif
     V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%if "%{platform}" == "tegra186"
%define target_soc t186
%endif
%if "%{platform}" == "tegra210"
%define target_soc t210
%endif
     PLAT=tegra TARGET_SOC=%{target_soc} \
%else
     PLAT=%{platform} \
%endif
%if %{use_optee}
     SPD=opteed \
     BL32=/boot/tee-header_v2.bin \
     BL32_EXTRA1=/boot/tee-pager_v2.bin \
     BL32_EXTRA2=/boot/tee-pageable_v2.bin \
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
     LOG_LEVEL=30 \
     MV_DDR_PATH=$(pwd)/mv-ddr-marvell-%{mv_ddr_ver} \
%if "%{platform}" == "a3700"
     WTP=$(pwd)/A3700-utils-marvell-%{a3700_utils_ver} \
     CLOCKSPRESET=${clockspreset} DDR_TOPOLOGY=${ddr_topology} \
     USE_COHERENT_MEM=0 \
%if %{use_optee}
     LLC_ENABLE=1 LLC_SRAM=1 \
%endif
     BOOTDEV=${bootdev} PARTNUM=${partnum} \
     MARVELL_SECURE_BOOT=0 \
%endif
%if "%{platform}" == "a80x0_mcbin"
     SCP_BL2=$(pwd)/binaries-marvell-%{mv_bin_ver}/mrvl_scp_bl2.img \
%endif
%if "%{platform}" == "a80x0_mcbin" && 0
     BL33=/boot/ARMADA_EFI.fd \
%else
     BL33=/boot/u-boot.bin \
%endif
%if "%{platform}" == "a3700" || "%{platform}" == "a80x0_mcbin"
     mrvl_flash \
%if "%{platform}" == "a3700"
     mrvl_uart  \
%endif
%endif
     all fip
%if "%{platform}" == "a3700"
mv build build.${variant}
done
%endif
%else
%if "%{platform}" == "hikey"
     SCP_BL2=/boot/mcuimage.bin \
     BL33=/boot/u-boot.bin \
     all fip
%else
%if "%{platform}" == "hikey960"
     SCP_BL2=/boot/lpm3.img \
     BL33=/boot/BL33_AP_UEFI.fd \
     all fip
%else
%if "%{platform}" == "poplar"
     BL33=/boot/u-boot.bin \
     POPLAR_DRAM_SIZE=${dram_size} \
     all fip
mv build build.${dram_size}
make %{?_smp_mflags} V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
     PLAT=poplar POPLAR_RECOVERY=1 \
     BL33=/boot/u-boot.bin \
     POPLAR_DRAM_SIZE=${dram_size} \
     all fip
mv build build.${dram_size}.recovery
done
%else
%if "%{platform}" == "rpi3"
     BL33=/boot/vc/u-boot.bin \
     RPI3_PRELOADED_DTB_BASE=0x01000000 \
     RPI3_DIRECT_LINUX_BOOT=1 \
     RPI3_RUNTIME_UART=1 \
     all
%else
%if "%{platform}" == "qemu"
     BL33=%{_datadir}/qemu/qemu-uefi-aarch64.bin \
     all fip
%else
     all
%endif
%endif
%endif
%endif
%endif
%endif
%endif

%install
%if "%{platform}" == ""
mkdir -p %{buildroot}%{_bindir}
install -m 755 tools/fiptool/fiptool %{buildroot}%{_bindir}/fiptool

%if %{with A3700_tools}
pushd A3700-utils-marvell-%{a3700_utils_ver}
# No need to have a _linux suffix on Linux
install -D -m 0755 wtptp/src/TBB_Linux/release/TBB_linux %{buildroot}%{_bindir}/TBB
install -D -m 0755 wtptp/src/Wtpdownloader_Linux/WtpDownload_linux %{buildroot}%{_bindir}/WtpDownload
popd
%endif
%else

export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true

mkdir -p %{buildroot}%{_datadir}/%{name}

%if 0%{?debug_build}
%global dir debug
%else
%global dir release
%endif
%define outdir build/%{platform}/%{dir}
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%define outdir build/tegra/%{target_soc}/%{dir}
%endif
%if "%{platform}" == "a3700"
for v in %{variants}; do
  outdir=build.${v}/%{platform}/%{dir}
  destdir=%{buildroot}%{_datadir}/%{name}/${v}
  install -D -m 0644 ${outdir}/bl1.bin ${destdir}/bl1.bin
  install -D -m 0644 ${outdir}/bl2.bin ${destdir}/bl2.bin
  install -D -m 0644 ${outdir}/bl31.bin ${destdir}/bl31.bin
  install -D -m 0644 ${outdir}/fip.bin ${destdir}/fip.bin
  install -D -m 0644 ${outdir}/flash-image.bin ${destdir}/flash-image.bin
  install -D -m 0644 ${outdir}/uart-images/TIM_ATF.bin ${destdir}/uart/TIM_ATF.bin
  install -D -m 0644 ${outdir}/uart-images/boot-image_h.bin ${destdir}/uart/boot-image_h.bin
  install -D -m 0644 ${outdir}/uart-images/wtmi_h.bin ${destdir}/uart/wtmi_h.bin
done
%else
%if "%{platform}" == "poplar"
for v in one_gig two_gig one_gig.recovery two_gig.recovery; do
  outdir=build.${v}/%{platform}/%{dir}
  destdir=%{buildroot}%{_datadir}/%{name}/${v}
  install -D -m 0644 ${outdir}/bl1.bin ${destdir}/bl1.bin
  install -D -m 0644 ${outdir}/fip.bin ${destdir}/fip.bin
done
mkdir -p %{buildroot}%{_includedir}/%{name}
install -D -m 0644 plat/hisilicon/poplar/include/poplar_layout.h %{buildroot}%{_includedir}/%{name}/
%else

# u-boot for rockchip requires bl31.elf file
%if "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399" || "%{platform}" == "zynqmp"
install -D -m 0644 %{outdir}/bl31/bl31.elf %{buildroot}%{_datadir}/%{name}/bl31.elf
%else
install -D -m 0644 %{outdir}/bl31.bin %{buildroot}%{_datadir}/%{name}/bl31.bin
%endif

%if "%{platform}" == "a80x0_mcbin" || "%{platform}" == "hikey" || "%{platform}" == "hikey960" || "%{platform}" == "qemu" || "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/bl1.bin %{buildroot}%{_datadir}/%{name}/bl1.bin
install -D -m 0644 %{outdir}/fip.bin %{buildroot}%{_datadir}/%{name}/fip.bin
%endif
%if "%{platform}" == "a80x0_mcbin" || "%{platform}" == "hikey" || "%{platform}" == "hikey960" || "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/bl2.bin %{buildroot}%{_datadir}/%{name}/bl2.bin
%endif
%if "%{platform}" == "rpi3"
install -D -m 0644 %{outdir}/armstub8.bin %{buildroot}/boot/vc/armstub8.bin
%endif
%if "%{platform}" == "rpi4"
install -D -m 0644 %{outdir}/bl31.bin %{buildroot}/boot/vc/armstub8-rpi4.bin
%endif
%if "%{platform}" == "a80x0_mcbin"
install -D -m 0644 %{outdir}/ble.bin %{buildroot}%{_datadir}/%{name}/ble.bin
install -D -m 0644 %{outdir}/flash-image.bin %{buildroot}%{_datadir}/%{name}/flash-image.bin
%endif

%endif
%endif

%endif

%if "%{platform}" == "rpi3" || "%{platform}" == "rpi4"
%post
if mountpoint -q /boot/efi; then
  if ! [[ "$(readlink -f /boot/efi)" -ef "$(readlink -f /boot/vc)" ]]; then
    cp /boot/vc/armstub8* /boot/efi/
  fi
fi
%endif

%files
%defattr(-,root,root)
%license license.rst
%doc docs/about/acknowledgements.rst docs/process/contributing.rst docs/about/maintainers.rst readme.rst dco.txt
%if "%{platform}" != ""
%{_datadir}/%{name}
%endif
%if "%{platform}" == "rpi3" || "%{platform}" == "rpi4"
/boot/vc/armstub8*
%endif

%if "%{platform}" == ""
%files tools
%defattr(-,root,root)
%{_bindir}/fiptool
%if %{with A3700_tools}
%{_bindir}/TBB
%{_bindir}/WtpDownload
%endif
%endif

%if "%{platform}" == "poplar"
%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%endif

%changelog
* Thu Jan  6 2022 Ivan Ivanov <ivan.ivanov@suse.com>
- Auto install on RPi4
* Fri Dec 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.6:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.md
- Update mv-ddr-marvell-armada-atf-master to latest version
- Drop upstreamed patch:
  * atf-2411053.diff
- Add patch to allow to use non-git checkouts:
  * atf-allow-non-git-dir.patch
* Tue Jul  6 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update mv-ddr-marvell to use master branch as upstream recommends
  This fixes build of a80x0_mcbin
- Update A3700-utils-marvell to use master branch as upstream recommends
- Re-enable A3700 tools with patch:
  * fix-A3700-gcc11.patch
- And refresh patch:
  * A3700_utils-drop-git.patch
* Thu Jun 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable A3700 tools until fixed upstream:
  https://github.com/MarvellEmbeddedProcessors/A3700-utils-marvell/issues/22
* Thu Jun  3 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix rk3399 build:
  * atf-2411053.diff
* Thu May 20 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.5:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.rst#version-25
* Fri Dec 11 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to version 2.4:
  * changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/tree/docs/change-log.rst#n7
- Replace mv-ddr-marvell-armada-atf-mainline.tar.gz with
  mv-ddr-marvell-mv-ddr-devel.tar.gz to match the upstream requirements
- Drop upstream patch:
  * mv-ddr.diff
* Sat Oct 17 2020 Andreas Färber <afaerber@suse.de>
- Fix BUILD_MESSAGE_TIMESTAMP (don't try parsing deleted .changes)
- Clean up rpi4 build
- Drop comments to avoid RPM errors about %%else and %%endif end of line
- Update mv-ddr-marvell from mv_ddr-atf-mainline branch to mv-ddr-devel 14.0.0
  * Add mv-ddr.diff (from d:A:F:Contrib:MacchiatoBin) to fix a warning treated as error
  * Add a _service to clarify its origin and facilitate future updates
- Update A3700-utils-marvell from armada-18.12 to armada-18.12-fixed branch
  * Drop A3700_utils-TBB-Split-INCDIR-from-LIBDIR.patch (merged)
  * Drop A3700_utils-TBB-Fix-building-for-Crypto-6.0-and-later.patch (merged)
  * Actually apply A3700_utils-drop-git.patch (output cleanup)
- Build and package A3700 utils as part of -tools (non-noarch, ensure PIE)
- Build the tools for all architectures again
- Add binaries-marvell from binaries-marvell-armada-SDK10.0.1.0 branch
- Add a80x0_mcbin and extend a3700 to build and package all needed files
  * Suppress OP-TEE for now, as it fails to initialize
* Fri Oct 16 2020 Andreas Färber <afaerber@suse.de>
- Build fixes for a3700 and a80x0_mcbin
* Thu Jul  2 2020 Nicolas Patricio Saenz Julienne <nsaenzjulienne@suse.com>
- Add rpi4
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable debug on imx8mq to fix build
* Thu Apr 23 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.3:
  * Add support for Armv8.4-SecEL2 extension through the SPCI defined SPMD/SPMC components.
  * Build option to support EL2 context save and restore in the secure world (CTX_INCLUDE_EL2_REGS).
  * Add support for SMCCC v1.2 (introducing the new SMCCC_ARCH_SOC_ID SMC).
    Note that the support is compliant, but the SVE registers save/restore will be done as part of future S-EL2/SPM development.
  * Enhanced BL2 bootloader flow to load secure partitions based on firmware configuration data (fconf).
  * Changes necessary to support SEPARATE_NOBITS_REGION feature
  * TSP and BL2_AT_EL3: Add Position Independent Execution PIE support
  * Enable MTE support
  * Enable Link Time Optimization in GCC
  * Add CPU support:
  - cortex-a57: Enable higher performance non-cacheable load forwarding
  - Hercules: Workaround for Errata 1688305
  - Klein: Support added for Klein CPU
  - Matterhorn: Support added for Matterhorn CPU
  * Full changelog:  https://trustedfirmware-a.readthedocs.io/en/latest/change-log.html#version-2-3
* Sat Feb  1 2020 Matwey Kornilov <matwey.kornilov@gmail.com>
- Initial implementation for Marvel A3700 platform
* Thu Oct 24 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch to _multibuild system
- Update to 2.2:
  * Enable Pointer Authentication (PAuth) support for Secure World
  - Adds support for ARMv8.3-PAuth in BL1 SMC calls and BL2U
    image for firmware updates.
  * Enable Memory Tagging Extension (MTE) support in both secure
    and non-secure worlds
  - Adds support for the new Memory Tagging Extension arriving
    in ARMv8.5. MTE support is now enabled by default on
    systems that support it at EL0.
  - To enable it at ELx for both the non-secure and the secure
    world, the compiler flag CTX_INCLUDE_MTE_REGS includes
    register saving and restoring when necessary in order to
    prevent information leakage between the worlds.
  * Add support for Branch Target Identification (BTI)
  * Full changelog: https://trustedfirmware-a.readthedocs.io/en/latest/change-log.html#version-2-2
- Drop upstreamed patches:
  * arm-trusted-firmware_hikey960_race.patch
  * arm-trusted-firmware_poplar_mmc_dma.patch
  * arm-trusted-firmware_zynqmp_ipi.patch
* Wed Sep  4 2019 Andreas Färber <afaerber@suse.de>
- Add zynqmp
  * arm-trusted-firmware_zynqmp_ipi.patch
* Thu Aug  1 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add initial bits for a80x0_mcbin support for MacchiatoBin
* Sun Jun 16 2019 Andreas Färber <afaerber@suse.de>
- rpi3: By now building okay with OP-TEE
- rpi3: Replace dependency on deprecated bootstrap code with U-Boot
- rpi3: Change installation location (adopted from u-boot-rpi3)
- poplar: Fix eMMC DMA FIFO breaking U-Boot eMMC access
  (https://review.trustedfirmware.org/c/TF-A/trusted-firmware-a/+/1230)
  arm-trusted-firmware_poplar_mmc_dma.patch
- poplar: Build for both 2 GiB and 1 GiB boards (b96o#834)
* Sat Jun  8 2019 Andreas Färber <afaerber@suse.de>
- Add imxmq and imxmm
* Sat Jun  8 2019 Andreas Färber <afaerber@suse.de>
- Fix build date by escaping %%S (which expanded to %%SOURCE).
- hikey960: Avoid a race condition (boo#1134788)
  arm-trusted-firmware_hikey960_race.patch
* Tue Apr  9 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to v2.1:
  * Add ARMv8.3 pointer authentication in the normal and secure worlds
  * Cortex-Axx workarounds for erratums
  * New platforms
  * Full changelog: https://git.trustedfirmware.org/TF-A/trusted-firmware-a.git/about/docs/change-log.rst#version-2-1
- Remove outdated patch:
  * hikey960.diff
* Thu Mar 28 2019 Andreas Färber <afaerber@suse.de>
- rpi3: Package armstub8.bin, fip.bin, bl1.bin, bl2.bin
* Sun Nov 11 2018 afaerber@suse.de
- pre_checkin.sh: Fix package names for sun50i_{a64,h6}
* Sun Nov  4 2018 afaerber@suse.de
- Add imx8qm, imx8qx, sun50i_a64, sun50i_h6
* Sun Nov  4 2018 afaerber@suse.de
- Update to v2.0
  * Drop upstream patches
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
  * fip_create wrapper is no longer built (use fiptool instead)
  * Set BL33 for qemu
* Sun Jun  3 2018 afaerber@suse.de
- Conditionally enable OP-TEE as BL32
* Sun Jun  3 2018 afaerber@suse.de
- Add rpi3
* Sun Jun  3 2018 afaerber@suse.de
- Set BUILD_MESSAGE_TIMESTAMP for reproducible builds
- Simplify tegra packaging, reusing %%target_soc
* Fri Jun  1 2018 afaerber@suse.de
- Address CVE-2018-3639 (bsc#1085308)
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
* Thu May 31 2018 afaerber@suse.de
- hikey960.diff: Fix assertion on HiKey 960 (b9o#739)
* Thu May 31 2018 afaerber@suse.de
- Package bl2 for hikey and hikey960
* Mon May 21 2018 afaerber@suse.de
- Add tegra186
* Mon May 21 2018 afaerber@suse.de
- Package poplar_layout.h header for l-loader in devel package
* Sun May 20 2018 afaerber@suse.de
- Build recovery version of poplar, too
* Sun May 20 2018 afaerber@suse.de
- Adopt %%license
- Add poplar
- Prepare tegra186
* Sun May 20 2018 afaerber@suse.de
- Update to v1.5
  * Dropped upstream patches:
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_pfr0.patch
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Feb 10 2018 afaerber@suse.de
- Apply fiptool patches to tools package, too (b9o#633)
- Prepare for detecting PIE support (gh#ARM-software/tf-issues#519)
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
* Sat Feb 10 2018 afaerber@suse.de
- Implement SMCCC v1.1 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Jan 27 2018 afaerber@suse.de
- Pad HiKey FIP to avoid hanging fastboot transfer (b9o#633)
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
* Sat Jan 27 2018 afaerber@suse.de
- Add CVE-2017-5715 output (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
* Mon Jan 22 2018 afaerber@suse.de
- Use debug builds
* Fri Jan 12 2018 afaerber@suse.de
- rk3399: Don't require cross binutils (let cross gcc choose which)
* Fri Jan 12 2018 afaerber@suse.de
- hikey960: Build fip and require EDK2 for SCP_BL2 and BL33
- Refresh CVE-2017-5715 patches (bsc#1074741)
  Drop arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
  Add arm-trusted-firmware_cve-2017-5715_pfr0.patch
- Suppress debuginfo for firmware
* Sun Jan  7 2018 afaerber@suse.de
- Make noarch so that it can be exported
* Sun Jan  7 2018 afaerber@suse.de
- hikey: Build fip and require EDK2 for SCP_BL2
- Add tegra210
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey960
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey
- Clean up pre_checkin.sh
- Don't package bl31.bin for Rockchip, we need bl31.elf only
* Fri Jan  5 2018 afaerber@suse.de
- Require arm-none gcc for RK3399
* Fri Jan  5 2018 afaerber@suse.de
- Address CVE-2017-5715 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
* Wed Jan  3 2018 matwey.kornilov@gmail.com
- Return lost doc files
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- Package bl31.elf
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- acknowledgements.md renamed to acknowledgements.rst
* Thu Dec 28 2017 matwey.kornilov@gmail.com
- Version 1.4
* Mon Dec 26 2016 afaerber@suse.de
- Update to v1.3 final
* Sat Oct  8 2016 afaerber@suse.de
- Initial
